.. emsuite documentation master file, created by
   sphinx-quickstart on Wed Jan 14 18:18:27 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Tuning
======

The **tuning** module calculates the effects of varying positions of external point charges on 
molecular properties — generating electrostatic tuning maps for visualization.

.. grid:: 2
   :gutter: 2

   .. grid-item-card:: Tutorials
      :link: tutorials/index
      :link-type: doc

      Step-by-step guides to learn tuning calculations.

   .. grid-item-card:: How-to Guides
      :link: how-to/index
      :link-type: doc

      Recipes for specific tasks.

   .. grid-item-card:: Reference
      :link: reference/index
      :link-type: doc

      Input parameters, files and formats, CLI options and outputs.

   .. grid-item-card:: Explanation
      :link: explanation/index
      :link-type: doc

      Background theory and concepts.

.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials/index
   how-to/index
   reference/index
   explanation/index

